@@ -25,9 +25,9 @@ typedef struct {
 #define STORAGE_RLE         1
 
 #define CMAP_NORMAL         0
-#define CMAP_DITHERED       1   /* not supported */
-#define CMAP_SCREEN         2   /* not supported */
-#define CMAP_COLORMAP       3   /* not supported */
+#define CMAP_DITHERED       1   /* can't handle this */
+#define CMAP_SCREEN         2   /* can't handle this */
+#define CMAP_COLORMAP       3   /* can't handle this */
 
 #endif
 
